@@ -4,8 +4,8 @@
 use fil_actor_cron::{Actor as CronActor, ConstructorParams, Entry, State};
 use fil_actors_runtime::test_utils::*;
 use fil_actors_runtime::SYSTEM_ACTOR_ADDR;
+use fvm_ipld_encoding::RawBytes;
 use fvm_shared::address::Address;
-use fvm_shared::encoding::RawBytes;
 use fvm_shared::error::ExitCode;
 
 fn construct_runtime() -> MockRuntime {
@@ -104,7 +104,7 @@ fn epoch_tick_with_entries() {
         RawBytes::default(),
         0u8.into(),
         RawBytes::default(),
-        ExitCode::Ok,
+        ExitCode::OK,
     );
     rt.expect_send(
         entry2.receiver,
@@ -112,7 +112,7 @@ fn epoch_tick_with_entries() {
         RawBytes::default(),
         0u8.into(),
         RawBytes::default(),
-        ExitCode::ErrIllegalArgument,
+        ExitCode::USR_ILLEGAL_ARGUMENT,
     );
     rt.expect_send(
         entry3.receiver,
@@ -120,7 +120,7 @@ fn epoch_tick_with_entries() {
         RawBytes::default(),
         0u8.into(),
         RawBytes::default(),
-        ExitCode::Ok,
+        ExitCode::OK,
     );
     rt.expect_send(
         entry4.receiver,
@@ -128,7 +128,7 @@ fn epoch_tick_with_entries() {
         RawBytes::default(),
         0u8.into(),
         RawBytes::default(),
-        ExitCode::Ok,
+        ExitCode::OK,
     );
 
     epoch_tick_and_verify(&mut rt);
